@@ -66,6 +66,10 @@ type Pager struct {
 
 	searchString  string
 	searchPattern *regexp.Regexp
+
+	// This should never be null while paging. Configured in NewPager().
+	searchHistory *SearchHistory
+
 	filterPattern *regexp.Regexp
 
 	// We used to have a "Following" field here. If you want to follow, set
@@ -115,7 +119,12 @@ type Pager struct {
 
 	WithTerminalFg bool // If true, don't set linePrefix
 
-	// Length of the longest line displayed. This is used for limiting scrolling to the right.
+	// If false, don't highlight lines with search hits (but still highlight the
+	// actual hits)
+	WithSearchHitLineBackground bool
+
+	// Length of the longest line displayed. This is used for limiting scrolling
+	// to the right.
 	longestLineLength int
 
 	// Bookmarks that you can come back to.
@@ -214,19 +223,20 @@ func NewPager(readers ...*reader.ReaderImpl) *Pager {
 	}
 
 	pager := Pager{
-		readers:          readers,
-		currentReader:    0,
-		readerSwitched:   make(chan struct{}, 1),
-		quit:             false,
-		ShowLineNumbers:  true, // Constant throghout the lifetime of the pager
-		showLineNumbers:  true, // Will be updated over time
-		ShowStatusBar:    true,
-		DeInit:           true,
-		SideScrollAmount: 16,
-		TabSize:          8, // This is what less defaults to
-		ScrollLeftHint:   textstyles.CellWithMetadata{Rune: '<', Style: twin.StyleDefault.WithAttr(twin.AttrReverse)},
-		ScrollRightHint:  textstyles.CellWithMetadata{Rune: '>', Style: twin.StyleDefault.WithAttr(twin.AttrReverse)},
-		scrollPosition:   newScrollPosition(name),
+		readers:                     readers,
+		currentReader:               0,
+		readerSwitched:              make(chan struct{}, 1),
+		quit:                        false,
+		ShowLineNumbers:             true, // Constant throghout the lifetime of the pager
+		showLineNumbers:             true, // Will be updated over time
+		ShowStatusBar:               true,
+		DeInit:                      true,
+		SideScrollAmount:            16,
+		TabSize:                     8, // This is what less defaults to
+		ScrollLeftHint:              textstyles.CellWithMetadata{Rune: '<', Style: twin.StyleDefault.WithAttr(twin.AttrReverse)},
+		ScrollRightHint:             textstyles.CellWithMetadata{Rune: '>', Style: twin.StyleDefault.WithAttr(twin.AttrReverse)},
+		scrollPosition:              newScrollPosition(name),
+		WithSearchHitLineBackground: true,
 	}
 
 	pager.mode = PagerModeViewing{pager: &pager}
@@ -235,6 +245,9 @@ func NewPager(readers ...*reader.ReaderImpl) *Pager {
 		FilterPattern: &pager.filterPattern,
 	}
 
+	searchHistory := BootSearchHistory("")
+	pager.searchHistory = &searchHistory
+
 	return &pager
 }
 
@@ -443,9 +456,7 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 		textstyles.TabSize = p.TabSize
 	}
 	consumeLessTermcapEnvs(screen.TerminalBackground(), chromaStyle, chromaFormatter)
-	styleUI(screen.TerminalBackground(), chromaStyle, chromaFormatter, p.StatusBarStyle, p.WithTerminalFg)
-
-	searchHistory = loadSearchHistory()
+	styleUI(screen.TerminalBackground(), chromaStyle, chromaFormatter, p.StatusBarStyle, p.WithTerminalFg, p.WithSearchHitLineBackground)
 
 	p.screen = screen
 	p.mode = PagerModeViewing{pager: p}
@@ -623,8 +634,17 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 			}
 
 		case eventMaybeDone:
-			// Do nothing. We got this just so that we'll do the QuitIfOneScreen
-			// check (above) as soon as highlighting is done.
+			// Man pages come pre-formatted for the screen width, and line
+			// numbers will mess that up. So we disable line numbers if we
+			// detect a man page by its contents.
+			//
+			// See also noLineNumbersDefault() where we use environment
+			// variables to try to detect man paging.
+			if p.haveLoadedManPage() && len(p.readers) == 1 {
+				p.ShowLineNumbers = false
+				p.showLineNumbers = false
+				log.Info("man page detected by contents, disabling line numbers")
+			}
 
 		case eventSpinnerUpdate:
 			spinner = event.spinner
